# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '/home/paul/PycharmProjects/pySprida/pySprida/gui/main.ui'
#
# Created by: PyQt5 UI code generator 5.15.1
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(802, 600)
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.label = QtWidgets.QLabel(self.centralwidget)
        self.label.setGeometry(QtCore.QRect(10, 10, 81, 18))
        self.label.setObjectName("label")
        self.config_path_select_button = QtWidgets.QPushButton(self.centralwidget)
        self.config_path_select_button.setGeometry(QtCore.QRect(420, 30, 121, 34))
        self.config_path_select_button.setObjectName("config_path_select_button")
        self.config_path = QtWidgets.QLineEdit(self.centralwidget)
        self.config_path.setGeometry(QtCore.QRect(10, 30, 401, 32))
        self.config_path.setObjectName("config_path")
        self.load_config_button = QtWidgets.QPushButton(self.centralwidget)
        self.load_config_button.setGeometry(QtCore.QRect(560, 30, 88, 34))
        self.load_config_button.setObjectName("load_config_button")
        self.generate_button = QtWidgets.QPushButton(self.centralwidget)
        self.generate_button.setGeometry(QtCore.QRect(10, 440, 161, 91))
        self.generate_button.setObjectName("generate_button")
        self.solver_selector = QtWidgets.QComboBox(self.centralwidget)
        self.solver_selector.setGeometry(QtCore.QRect(10, 110, 87, 32))
        self.solver_selector.setObjectName("solver_selector")
        self.solver_selector.addItem("")
        self.label_2 = QtWidgets.QLabel(self.centralwidget)
        self.label_2.setGeometry(QtCore.QRect(10, 90, 58, 18))
        self.label_2.setObjectName("label_2")
        self.label_3 = QtWidgets.QLabel(self.centralwidget)
        self.label_3.setGeometry(QtCore.QRect(190, 440, 58, 18))
        self.label_3.setObjectName("label_3")
        self.label_4 = QtWidgets.QLabel(self.centralwidget)
        self.label_4.setGeometry(QtCore.QRect(190, 460, 58, 18))
        self.label_4.setObjectName("label_4")
        self.label_5 = QtWidgets.QLabel(self.centralwidget)
        self.label_5.setGeometry(QtCore.QRect(190, 480, 58, 18))
        self.label_5.setObjectName("label_5")
        self.label_6 = QtWidgets.QLabel(self.centralwidget)
        self.label_6.setGeometry(QtCore.QRect(190, 500, 58, 18))
        self.label_6.setObjectName("label_6")
        self.status = QtWidgets.QLabel(self.centralwidget)
        self.status.setGeometry(QtCore.QRect(260, 440, 531, 18))
        self.status.setObjectName("status")
        self.solution_type = QtWidgets.QLabel(self.centralwidget)
        self.solution_type.setGeometry(QtCore.QRect(260, 460, 531, 18))
        self.solution_type.setObjectName("solution_type")
        self.solution_value = QtWidgets.QLabel(self.centralwidget)
        self.solution_value.setGeometry(QtCore.QRect(260, 480, 201, 18))
        self.solution_value.setObjectName("solution_value")
        self.ub_value = QtWidgets.QLabel(self.centralwidget)
        self.ub_value.setGeometry(QtCore.QRect(260, 500, 231, 18))
        self.ub_value.setObjectName("ub_value")
        self.loss_progress = QtWidgets.QProgressBar(self.centralwidget)
        self.loss_progress.setGeometry(QtCore.QRect(190, 520, 291, 23))
        self.loss_progress.setProperty("value", 0)
        self.loss_progress.setObjectName("loss_progress")
        self.pushButton = QtWidgets.QPushButton(self.centralwidget)
        self.pushButton.setGeometry(QtCore.QRect(140, 310, 121, 34))
        self.pushButton.setObjectName("pushButton")
        self.label_7 = QtWidgets.QLabel(self.centralwidget)
        self.label_7.setGeometry(QtCore.QRect(140, 90, 58, 18))
        self.label_7.setObjectName("label_7")
        self.label_8 = QtWidgets.QLabel(self.centralwidget)
        self.label_8.setGeometry(QtCore.QRect(270, 90, 58, 18))
        self.label_8.setObjectName("label_8")
        self.label_9 = QtWidgets.QLabel(self.centralwidget)
        self.label_9.setGeometry(QtCore.QRect(400, 90, 58, 18))
        self.label_9.setObjectName("label_9")
        self.solver_edit_button = QtWidgets.QPushButton(self.centralwidget)
        self.solver_edit_button.setGeometry(QtCore.QRect(10, 310, 121, 34))
        self.solver_edit_button.setObjectName("solver_edit_button")
        self.teacher_list = QtWidgets.QListWidget(self.centralwidget)
        self.teacher_list.setGeometry(QtCore.QRect(140, 110, 121, 192))
        self.teacher_list.setObjectName("teacher_list")
        self.subject_list = QtWidgets.QListWidget(self.centralwidget)
        self.subject_list.setGeometry(QtCore.QRect(270, 110, 121, 192))
        self.subject_list.setObjectName("subject_list")
        self.groups_list = QtWidgets.QListWidget(self.centralwidget)
        self.groups_list.setGeometry(QtCore.QRect(400, 110, 121, 192))
        self.groups_list.setObjectName("groups_list")
        self.save_problem_button = QtWidgets.QPushButton(self.centralwidget)
        self.save_problem_button.setGeometry(QtCore.QRect(10, 400, 101, 34))
        self.save_problem_button.setObjectName("save_problem_button")
        self.export_solution_button = QtWidgets.QPushButton(self.centralwidget)
        self.export_solution_button.setGeometry(QtCore.QRect(120, 400, 111, 34))
        self.export_solution_button.setObjectName("export_solution_button")
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 802, 30))
        self.menubar.setObjectName("menubar")
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(MainWindow)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)

        self.retranslateUi(MainWindow)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "pySprida"))
        self.label.setText(_translate("MainWindow", "Config File"))
        self.config_path_select_button.setText(_translate("MainWindow", "Browse"))
        self.load_config_button.setText(_translate("MainWindow", "Load"))
        self.generate_button.setText(_translate("MainWindow", "Generate"))
        self.solver_selector.setItemText(0, _translate("MainWindow", "LP"))
        self.label_2.setText(_translate("MainWindow", "Solver"))
        self.label_3.setText(_translate("MainWindow", "Status:"))
        self.label_4.setText(_translate("MainWindow", "Type:"))
        self.label_5.setText(_translate("MainWindow", "Solution:"))
        self.label_6.setText(_translate("MainWindow", "UB:"))
        self.status.setText(_translate("MainWindow", "-"))
        self.solution_type.setText(_translate("MainWindow", "-"))
        self.solution_value.setText(_translate("MainWindow", "-"))
        self.ub_value.setText(_translate("MainWindow", "-"))
        self.pushButton.setText(_translate("MainWindow", "Edit Teachers"))
        self.label_7.setText(_translate("MainWindow", "Teacher"))
        self.label_8.setText(_translate("MainWindow", "Subjects"))
        self.label_9.setText(_translate("MainWindow", "Groups"))
        self.solver_edit_button.setText(_translate("MainWindow", "Edit Solver"))
        self.save_problem_button.setText(_translate("MainWindow", "Save problem"))
        self.export_solution_button.setText(_translate("MainWindow", "Export solution "))



import json
from pathlib import Path

import xlsxwriter
from PyQt5 import QtWidgets, uic, QtCore, QtGui
import sys

from PyQt5.QtGui import QPixmap, QScreen
from PyQt5.QtWidgets import QMessageBox, QFileDialog
from mip import OptimizationStatus

from pySprida.data.dataContainer import DataContainer
from pySprida.data.lpData import LPData
from pySprida.gui.lpSolverWindow import LPSolverWindow
from pySprida.gui.main import Ui_MainWindow
from pySprida.gui.solution_window import SolutionWindow
from pySprida.solver.lpSolver import LPSolver


def info_ok_box(text, name="Info"):
    msgBox = QMessageBox()
    msgBox.setIcon(QMessageBox.Information)
    msgBox.setText(text)
    msgBox.setWindowTitle(name)
    msgBox.setStandardButtons(QMessageBox.Ok)
    msgBox.exec()


class MainWindow(QtWidgets.QMainWindow):

    def __init__(self, primary_screen, *args, **kwargs):
        super().__init__(*args, **kwargs)

        self.ui = Ui_MainWindow()
        self.ui.setupUi(self)
        self.primary_screen = primary_screen

        self.ui.config_path_select_button.clicked.connect(self.select_config_file)
        self.ui.load_config_button.clicked.connect(self.load_config)
        self.ui.generate_button.clicked.connect(self.generate)
        self.ui.solver_edit_button.clicked.connect(self.open_solver_edit_window)
        self.ui.save_problem_button.clicked.connect(self.save_problem)
        self.ui.export_solution_button.clicked.connect(self.export_solution)

        self.container = None
        self.solution = None
        # self.load_debug_data()

    def export_solution(self):
        if self.solution is None:
            info_ok_box("Generate a solution first")
            return
        name = QFileDialog.getSaveFileName(
            self,
            'Save File',
            "/home/pauli/Dokumente/Pfadfinder/Schulung_neu/Schulungen/21/Stunde- und Raumplan/erste Pläne vom 12.04/",
            "*.xlsx")[0]
        workbook = xlsxwriter.Workbook(name)
        worksheet = workbook.add_worksheet()
        mapping_matrix = self.solution.get_mapping_matrix()
        subject_names = self.container.get_subject_names()
        gtypes_names = self.container.get_group_names()
        for i, sub_name in enumerate(subject_names):
            worksheet.write(0, 1 + i * len(gtypes_names), sub_name)
            for j, gname in enumerate(gtypes_names):
                worksheet.write(1, 1 + i * len(gtypes_names) + j, gname)
        worksheet.set_column(1, len(subject_names) * len(gtypes_names) + 1, 3)
        for i, teacher in enumerate(self.container.teachers):
            worksheet.write(i + 2, 0, teacher.name)
            for j, selected in enumerate(mapping_matrix[i]):
                if selected:
                    worksheet.write(i + 2, j + 1, "x")
                else:
                    worksheet.write(i + 2, j + 1, "")
        workbook.close()

    def save_problem(self):
        if self.container is None:
            info_ok_box("Load some data first")
            return
        json_data = self.container.to_json()
        name = QFileDialog.getSaveFileName(self, 'Save File', "a_name.json", "*.json")[0]
        if name:
            with open(name, 'w', encoding="UTF-8") as f:
                json.dump(json_data, f, indent=4, sort_keys=True, ensure_ascii=False)

    def select_config_file(self):
        data_path, _ = QtWidgets.QFileDialog.getOpenFileName(
            None, 'Open File', r"/home/pauli/Dokumente/Pfadfinder/Schulung_neu/Schulungen/21/Stunde- und Raumplan/erste Pläne vom 12.04/", '*.json')
        self.ui.config_path.setText(data_path)

    def load_config(self):
        path = self.ui.config_path.text()
        self.container = DataContainer()
        try:
            self.container.load_data(Path(path))
        except (IsADirectoryError, FileNotFoundError):
            info_ok_box(f"File {str(path)} was not found!")
        self.load_preview_data()

    def load_preview_data(self):
        self.ui.teacher_list.clear()
        self.ui.subject_list.clear()
        self.ui.groups_list.clear()
        for teacher in self.container.teachers:
            self.ui.teacher_list.addItem(teacher.name)
        for group in self.container.groups:
            self.ui.groups_list.addItem(group.name)
        for subject_type in self.container.subject_types:
            self.ui.subject_list.addItem(subject_type.name)

    def generate(self):
        if self.container is None:
            info_ok_box("Load some data first")
            return
        solver = self.ui.solver_selector.currentText()
        if solver == "LP":
            problem = LPData(self.container)
            self.solver = LPSolver(problem, self.container)
            self.solver.finished.connect(self.show_solution)
            self.solver.start()
            self.ui.generate_button.setText("Working")
            self.ui.generate_button.setDisabled(True)
            self.ui.status.setText("Working")
        else:
            info_ok_box(f"No solver with the name: {str(solver)}")
            raise Exception("Wrong solver")

    def show_solution(self, solution):
        self.ui.generate_button.setText("Generate")
        self.ui.generate_button.setDisabled(False)
        self.ui.status.setText("Finished")
        self.ui.solution_type.setText(solution.status_name)

        if solution.relaxed_loss:
            self.ui.loss_progress.setMaximum(solution.relaxed_loss)
            self.ui.ub_value.setText(str(solution.relaxed_loss))
        if solution.loss:
            self.ui.loss_progress.setValue(solution.loss)
            self.ui.solution_value.setText(str(solution.loss))
        if solution.status == OptimizationStatus.FEASIBLE or solution.status == OptimizationStatus.OPTIMAL:
            self.solution = solution
            self.solution_window = SolutionWindow(solution, self.container)
            self.solution_window.show()
        else:
            self.ui.ub_value.setText("-")
            self.ui.solution_value.setText("-")
            self.ui.loss_progress.setValue(0)

    def set_solver_status(self):
        print("Test")

    def load_debug_data(self):
        self.ui.config_path.setText(r"/home/paul/PycharmProjects/pySprida/testData/csv_config2021.json")
        self.load_config()

    def open_solver_edit_window(self):
        if self.container is None:
            info_ok_box("Load some data first")
            return
        self.lp_edit_window = LPSolverWindow(self.container)
        self.lp_edit_window.show()



import logging
import sys
from pathlib import Path
import numpy as np
from PyQt5 import QtCore, QtGui, QtWidgets
from PyQt5.QtCore import Qt, QEvent, pyqtSignal
from PyQt5.QtGui import QColor, QPalette, QBrush
from PyQt5.QtWidgets import QTableView, QDesktopWidget, QStyledItemDelegate, QStyle, QWidget, QMainWindow

from pySprida.data.dataContainer import DataContainer
from pySprida.data.solution import Solution


class ColoredMappingTableModel(QtCore.QAbstractTableModel):
    def __init__(self, solution: Solution, data_container: DataContainer):
        super(ColoredMappingTableModel, self).__init__()
        self.data_container = data_container
        self._mapping = solution.get_mapping_matrix()
        self._preferences = self.data_container.updated_pref
        self._teacher_names = data_container.get_teacher_names()
        self._group_names = data_container.get_group_names()
        self._subject_names = data_container.get_subject_names()
        self._num_lessons = solution.get_teacher_num_lessons()
        self._co_ref = data_container.get_teacher_co_ref()

    def update_pref(self, row, col, pref):
        self._preferences[row][col] = pref
        self.data_container.updated_pref = self._preferences

    def data(self, index, role):
        if role == Qt.DisplayRole:
            # See below for the nested-list data structure.
            # .row() indexes into the outer list,
            # .column() indexes into the sub-list
            if index.row() == 0:
                if index.column() == 0:
                    return "Num"
                else:
                    return self._subject_names[(index.column() - 1) // len(self._group_names)]
            elif index.row() == 1:
                if index.column() > 0:
                    return self._group_names[(index.column() - 1) % len(self._group_names)]
            else:
                if index.column() == 0:
                    return str(self._num_lessons[index.row() - 2])
                elif self._mapping[index.row() - 2][index.column() - 1]:
                    return "X"
            return ""
        if role == Qt.BackgroundRole:
            second_col = ((index.column() - 1) // len(self._group_names)) % 2
            if index.row() == 1:
                if second_col:
                    return QtGui.QColor("#9da1fc")
                else:
                    return QtGui.QColor("#bdc0ff")
            if index.row() > 1:
                if index.column() == 0:
                    if self._co_ref[index.row() - 2]:
                        return QtGui.QColor("#348feb")
                    else:
                        return QtGui.QColor("#ffffff")
                value = self._preferences[index.row() - 2][index.column() - 1]
                if value == 0:
                    return QtGui.QColor("#ffffff")
                elif value >= 1 and value <= 2:
                    if second_col:
                        return QtGui.QColor("#d95f5f")
                    else:
                        return QtGui.QColor("#ff7070")
                elif value == 6:
                    if second_col:
                        return QtGui.QColor("#f542ef")
                    else:
                        return QtGui.QColor("#9e289a")
                elif value == 0:
                    if second_col:
                        return QtGui.QColor("#d95f5f")
                    else:
                        return QtGui.QColor("#ff7070")
                elif value == -1:
                    if second_col:
                        return QtGui.QColor("#000000")
                    else:
                        return QtGui.QColor("#000000")
                elif value == 3:
                    if second_col:
                        return QtGui.QColor("#d4c23d")
                    else:
                        return QtGui.QColor("#ffea4a")
                else:
                    if second_col:
                        return QtGui.QColor("#6fcf3c")
                    else:
                        return QtGui.QColor("#89ff4a")

    def rowCount(self, index):
        # The length of the outer list.
        return len(self._mapping) + 2

    def columnCount(self, index):
        # The following takes the first sub-list, and returns
        # the length (only works if all rows are an equal length)
        return len(self._mapping[0]) + 1

    def headerData(self, section, orientation, role):
        # section is the index of the column/row.
        if role == Qt.DisplayRole:
            # if orientation == Qt.Horizontal:
            #    return str(self._data.columns[section])

            if orientation == Qt.Vertical:
                if section == 0:
                    return "Type"
                elif section == 1:
                    return "Kurs"
                else:
                    return str(self._teacher_names[section - 2])


class StyleDelegateForQTableWidget(QStyledItemDelegate):
    color_default = QColor("#aaedff")

    def paint(self, painter, option, index):
        if option.state & QStyle.State_Selected:
            option.palette.setColor(QPalette.HighlightedText, Qt.black)
            color = self.combineColors(self.color_default, self.background(option, index))
            option.palette.setColor(QPalette.Highlight, color)
        QStyledItemDelegate.paint(self, painter, option, index)

    def background(self, option, index):
        color = self.parent().model().data(index, Qt.BackgroundRole)
        return color

    @staticmethod
    def combineColors(c1, c2):
        c3 = QColor()
        c3.setRed((c1.red() + c2.red()) / 2)
        c3.setGreen((c1.green() + c2.green()) / 2)
        c3.setBlue((c1.blue() + c2.blue()) / 2)

        return c3


class ColoredMappingTableView(QTableView):
    adjusted_pref = pyqtSignal(int, int, int)

    def __init__(self, data_container: DataContainer):
        super().__init__()
        # We need this to allow navigating without editing
        self.catch = False

        self._data_container = data_container
        self._num_groups = data_container.num_groups
        self._num_courses = data_container.num_cources
        self._num_teachers = data_container.num_teacher
        for i in range(0, self._num_courses // self._num_groups):
            self.setSpan(0, i * self._num_groups + 1, 1, self._num_groups)

        self.setItemDelegate(StyleDelegateForQTableWidget(self))

        self.keys = [Qt.Key_1,
                     Qt.Key_2,
                     Qt.Key_3,
                     Qt.Key_4,
                     Qt.Key_5,
                     Qt.Key_R,
                     Qt.Key_N,
                     Qt.Key_Y]

    def ajust_size(self):
        self.setRowHeight(0, 1)
        self.setColumnWidth(0, 1)
        for i in range(self._num_courses):
            self.setColumnWidth(i + 1, 1)
        for i in range(self._num_teachers + 2):
            self.setRowHeight(i + 1, 1)

    def focusInEvent(self, event):
        self.catch = False
        return QTableView.focusInEvent(self, event)

    def focusOutEvent(self, event):
        self.catch = True
        return QTableView.focusOutEvent(self, event)

    def event(self, event):
        if event.type() == QEvent.KeyPress and event.key() in self.keys:
            self.adjust_pref(event.key())

        return QTableView.event(self, event)

    def adjust_pref(self, key):
        if key == Qt.Key_N:
            pref = -1
        elif key == Qt.Key_Y:
            pref = 6
        else:
            pref = self.keys.index(key) + 1
        selected = self.selectedIndexes()[0]
        row = selected.row()
        col = selected.column()

        self.model().update_pref(row - 2, col - 1, pref)
        self.update()
        self.adjusted_pref.emit(row - 2, col - 1, pref)


class SolutionWindow(QMainWindow):
    def __init__(self, solution, dataContainer):
        super().__init__()

        self.table = ColoredMappingTableView(dataContainer)
        self.model = ColoredMappingTableModel(solution, dataContainer)
        self.table.setModel(self.model)
        self.table.ajust_size()

        self.setCentralWidget(self.table)

        #dw = QDesktopWidget()
        #x = int(dw.width() * 0.7)
        #y = int(dw.height() * 0.7)
        #self.resize(x, y)
        self.adjustSize()
        self.setWindowTitle("PySprida-Solution")


if __name__ == "__main__":
    logging.basicConfig(level=logging.DEBUG)
    from pySprida.data.consolePrinter import ConsolePrinter
    printer = ConsolePrinter()

    container = DataContainer()
    container.load_data(Path("./testData/testProblem.json"))
    printer.printTeachers(container)
    printer.printGroups(container)

    app = QtWidgets.QApplication(sys.argv)
    window = SolutionWindow(Solution(np.random.randint(0, 2, (15 * 11 * 3)), container), container)
    window.show()
    app.exec_()



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'lpsolveredit.ui'
#
# Created by: PyQt5 UI code generator 5.15.1
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_LPSolverEdit(object):
    def setupUi(self, LPSolverEdit):
        LPSolverEdit.setObjectName("LPSolverEdit")
        LPSolverEdit.resize(328, 182)
        self.centralwidget = QtWidgets.QWidget(LPSolverEdit)
        self.centralwidget.setObjectName("centralwidget")
        self.label = QtWidgets.QLabel(self.centralwidget)
        self.label.setGeometry(QtCore.QRect(30, 10, 91, 18))
        self.label.setObjectName("label")
        self.label_2 = QtWidgets.QLabel(self.centralwidget)
        self.label_2.setGeometry(QtCore.QRect(30, 50, 131, 18))
        self.label_2.setObjectName("label_2")
        self.label_3 = QtWidgets.QLabel(self.centralwidget)
        self.label_3.setGeometry(QtCore.QRect(30, 90, 141, 18))
        self.label_3.setObjectName("label_3")
        self.max_time = QtWidgets.QLineEdit(self.centralwidget)
        self.max_time.setGeometry(QtCore.QRect(190, 10, 113, 32))
        self.max_time.setObjectName("max_time")
        self.equal_lesson_weight = QtWidgets.QLineEdit(self.centralwidget)
        self.equal_lesson_weight.setGeometry(QtCore.QRect(190, 50, 113, 32))
        self.equal_lesson_weight.setObjectName("equal_lesson_weight")
        self.equal_subject_weight = QtWidgets.QLineEdit(self.centralwidget)
        self.equal_subject_weight.setGeometry(QtCore.QRect(190, 90, 113, 32))
        self.equal_subject_weight.setObjectName("equal_subject_weight")
        LPSolverEdit.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(LPSolverEdit)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 328, 30))
        self.menubar.setObjectName("menubar")
        LPSolverEdit.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(LPSolverEdit)
        self.statusbar.setObjectName("statusbar")
        LPSolverEdit.setStatusBar(self.statusbar)

        self.retranslateUi(LPSolverEdit)
        QtCore.QMetaObject.connectSlotsByName(LPSolverEdit)

    def retranslateUi(self, LPSolverEdit):
        _translate = QtCore.QCoreApplication.translate
        LPSolverEdit.setWindowTitle(_translate("LPSolverEdit", "LP Solver Edit"))
        self.label.setText(_translate("LPSolverEdit", "Max time (sec)"))
        self.label_2.setText(_translate("LPSolverEdit", "Equal lessons weight"))
        self.label_3.setText(_translate("LPSolverEdit", "Equal subjects weight"))



from setuptools import setup, find_packages
import versioneer
import os


def resolve_requirements(file):
    requirements = []
    with open(file) as f:
        req = f.read().splitlines()
        for r in req:
            if r.startswith("-r"):
                requirements += resolve_requirements(
                    os.path.join(os.path.dirname(file), r.split(" ")[1]))
            else:
                requirements.append(r)
    return requirements


def read_file(file):
    with open(file) as f:
        content = f.read()
    return content


requirements = resolve_requirements(
    os.path.join(os.path.dirname(__file__), "requirements", 'install.txt'))

readme = read_file(os.path.join(os.path.dirname(__file__), "README.md"))


setup(
    name='pySprida',
    version=versioneer.get_version(),
    cmdclass=versioneer.get_cmdclass(),
    packages=find_packages(),
    url='',
    test_suite="unittest",
    long_description=readme,
    long_description_content_type='text/markdown',
    install_requires=requirements,
    tests_require=["coverage"],
    python_requires=">=3.7",
    author="Paul Kruse",
    maintainer='Paul Kruse',
    maintainer_email='paul.kruse@posteo.de',
    license='MIT',
)



from PyQt5.QtWidgets import QMainWindow

from pySprida.data.dataContainer import DataContainer
from pySprida.gui.lpsolveredit import Ui_LPSolverEdit


class LPSolverWindow(QMainWindow):

    def __init__(self, container: DataContainer, *args, **kwargs):
        super().__init__(*args, **kwargs)

        self.ui = Ui_LPSolverEdit()
        self.ui.setupUi(self)
        self.container = container
        config = container.solver_config["lp"]
        self.ui.max_time.setText(str(config["max_time"]))
        self.ui.equal_lesson_weight.setText(str(config["equal_lesson_weight"]))
        self.ui.equal_subject_weight.setText(str(config["equal_subject_weight"]))

        self.ui.max_time.textChanged.connect(self.max_time_change)
        self.ui.equal_lesson_weight.textChanged.connect(self.equal_lesson_weight_change)
        self.ui.equal_subject_weight.textChanged.connect(self.equal_subject_weighte_change)

    def max_time_change(self):
        if self.ui.max_time.text() == "":
            self.container.solver_config["lp"]["max_time"] = 0
            return
        self.container.solver_config["lp"]["max_time"] = float(self.ui.max_time.text())

    def equal_lesson_weight_change(self):
        if self.ui.equal_lesson_weight.text() == "":
            self.container.solver_config["lp"]["equal_lesson_weight"] = 0
            return
        self.container.solver_config["lp"]["equal_lesson_weight"] = float(self.ui.equal_lesson_weight.text())

    def equal_subject_weighte_change(self):
        if self.ui.equal_subject_weight.text() == "":
            self.container.solver_config["lp"]["equal_subject_weight"] = 0
            return
        self.container.solver_config["lp"]["equal_subject_weight"] = float(self.ui.equal_subject_weight.text())
